==> mvapich2-2.3.6.tar.gz: mvapich2-2.3.6/src/mpi/coll/tuning/alltoall/gen2_cma_INTEL_XEON_E5_2680_16_MLX_CX_FDR_1ppn.h <==
/*
 * Copyright (c) 2001-2021, The Ohio State University. All rights
 * reserved.
 *
 * This file is part of the MVAPICH2 software package developed by the
 * team members of The Ohio State University's Network-Based Computing
 * Laboratory (NBCL), headed by Professor Dhabaleswar K. (DK) Panda.
 *
 * For detailed copyright and licensing information, please refer to the
 * copyright file COPYRIGHT in the top level MVAPICH2 directory.
 */

#define GEN2_CMA__INTEL_XEON_E5_2680_16__MLX_CX_FDR__1PPN { \
	{		\
	4,		\
	{0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{64, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{128, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{256, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{512, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	},		\
	{		\
	8,		\
	{0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_RD_MV2},		\
	{4, &MPIR_Alltoall_RD_MV2},		\
	{8, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{64, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{128, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{256, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{512, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	},		\
	{		\
	16,		\
	{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_RD_MV2},		\
	{4, &MPIR_Alltoall_RD_MV2},		\
	{8, &MPIR_Alltoall_RD_MV2},		\
	{16, &MPIR_Alltoall_RD_MV2},		\
	{32, &MPIR_Alltoall_RD_MV2},		\
	{64, &MPIR_Alltoall_bruck_MV2},		\
	{128, &MPIR_Alltoall_bruck_MV2},		\
	{256, &MPIR_Alltoall_bruck_MV2},		\
	{512, &MPIR_Alltoall_bruck_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	},		\
	{		\
	32,		\
	{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_bruck_MV2},		\
	{4, &MPIR_Alltoall_bruck_MV2},		\
	{8, &MPIR_Alltoall_bruck_MV2},		\
	{16, &MPIR_Alltoall_bruck_MV2},		\
	{32, &MPIR_Alltoall_bruck_MV2},		\
	{64, &MPIR_Alltoall_bruck_MV2},		\
	{128, &MPIR_Alltoall_bruck_MV2},		\
	{256, &MPIR_Alltoall_bruck_MV2},		\
	{512, &MPIR_Alltoall_bruck_MV2},		\
	{1024, &MPIR_Alltoall_bruck_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	}		\
};

==> mvapich2-2.3.7-1.tar.gz: mvapich2-2.3.7-1/src/mpi/coll/tuning/alltoall/gen2_cma_INTEL_XEON_E5_2670_16_MLX_CX_FDR_1ppn.h <==
/*
 * Copyright (c) 2001-2022, The Ohio State University. All rights
 * reserved.
 *
 * This file is part of the MVAPICH2 software package developed by the
 * team members of The Ohio State University's Network-Based Computing
 * Laboratory (NBCL), headed by Professor Dhabaleswar K. (DK) Panda.
 *
 * For detailed copyright and licensing information, please refer to the
 * copyright file COPYRIGHT in the top level MVAPICH2 directory.
 */

#define GEN2_CMA__INTEL_XEON_E5_2670_16__MLX_CX_FDR__1PPN { \
	{		\
	4,		\
	{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{64, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{128, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{256, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{512, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	},		\
	{		\
	8,		\
	{0, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4, &MPIR_Alltoall_RD_MV2},		\
	{8, &MPIR_Alltoall_RD_MV2},		\
	{16, &MPIR_Alltoall_RD_MV2},		\
	{32, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{64, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{128, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{256, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{512, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	},		\
	{		\
	16,		\
	{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},		\
	20,		\
	{		\
	{1, &MPIR_Alltoall_RD_MV2},		\
	{2, &MPIR_Alltoall_RD_MV2},		\
	{4, &MPIR_Alltoall_RD_MV2},		\
	{8, &MPIR_Alltoall_RD_MV2},		\
	{16, &MPIR_Alltoall_RD_MV2},		\
	{32, &MPIR_Alltoall_RD_MV2},		\
	{64, &MPIR_Alltoall_RD_MV2},		\
	{128, &MPIR_Alltoall_bruck_MV2},		\
	{256, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{512, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1024, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{2048, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{4096, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{8192, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{16384, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{32768, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{65536, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{131072, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{262144, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{524288, &MPIR_Alltoall_Scatter_dest_MV2},		\
	{1048576, &MPIR_Alltoall_Scatter_dest_MV2}		\
	}		\
	}		\
};
